@@ -23,21 +23,13 @@
 #include "RrdaEncoder.h"
 #include "RrdaResource.h"
 #include "SettingConfig.h"
+#include "ThemeResource.h"
+#include "ClockPartsDraw.h"
 
 #ifdef _MSC_VER
 #define snprintf _snprintf
 #endif
 
-namespace {
-
-  class Resource {
-  public:
-    QMap<QString, QPixmap*> pixmap;
-    QMap<QString, QRect> offset;
-    QMap<QString, QString> option;
-  };
-};
-
 
 struct ThemeClockDraw::pImpl {
 
@@ -46,14 +38,16 @@ struct ThemeClockDraw::pImpl {
   QLabel* message_label_;
   bool theme_loaded_;
   QString theme_file_;
-  Resource theme_resource_;
+  ThemeResource theme_resource_;
   QRegion* region_;
   QVector<QPixmap> digital_pixmap_;
   QVector<QPoint> digital_positions_;
+  size_t scaling_percent_;
 
 
   pImpl(ThemeClockDraw* parent)
-    : message_label_(NULL), theme_loaded_(false), region_(NULL) {
+    : message_label_(NULL), theme_loaded_(false), region_(NULL),
+      scaling_percent_(100) {
 
     // テーマファイルのドラッグを促すフォームを作成
     message_label_ =
@@ -126,7 +120,7 @@ struct ThemeClockDraw::pImpl {
     SettingConfig setting(tags, data);
 
     // 画像の格納
-    Resource resource;
+    ThemeResource resource;
     loadPixmap(resource, "base/base_org", tags, rrda_encoder);
     loadPixmap(resource, "analog/hari_h", tags, rrda_encoder);
     loadPixmap(resource, "analog/hari_m", tags, rrda_encoder);
@@ -149,7 +143,7 @@ struct ThemeClockDraw::pImpl {
     loadDigitalCharacter(resource, tags, rrda_encoder);
 
     // デジタル文字の描画位置を設定
-    loadDigitalPosition(tags);
+    loadDigitalPosition(digital_positions_, tags);
 
     // 描画リソースが何もなければ、エラー
     if (resource.pixmap.empty()) {
@@ -163,7 +157,7 @@ struct ThemeClockDraw::pImpl {
 
 
   // 画像の読み出し
-  bool loadPixmap(Resource& resource, const QString& tag_name,
+  bool loadPixmap(ThemeResource& resource, const QString& tag_name,
                   const QMap<QString, QString>& tags,
                   RrdaEncoder& rrda_encoder) {
 
@@ -194,7 +188,7 @@ struct ThemeClockDraw::pImpl {
 
 
   // 対応する画像が既に resouce に登録されていなければならない
-  void loadOffset(Resource& resource, const QString& tag_name,
+  void loadOffset(ThemeResource& resource, const QString& tag_name,
                   const QString& x_tag, const QString& y_tag,
                   const QMap<QString, QString>& tags) {
 
@@ -212,7 +206,7 @@ struct ThemeClockDraw::pImpl {
 
 
   // オプションの読み出し
-  void loadOption(Resource& resource, const QString& tag_name,
+  void loadOption(ThemeResource& resource, const QString& tag_name,
                   const QMap<QString, QString>& tags) {
 
     // オプションの取得と登録
@@ -226,11 +220,11 @@ struct ThemeClockDraw::pImpl {
 
 
   // デジタル画像の読み出し
-  void loadDigitalCharacter(Resource& resource,
+  void loadDigitalCharacter(ThemeResource& resource,
                             QMap<QString, QString>& tags,
                             RrdaEncoder& rrda_encoder) {
 
-    Resource digital_resource;
+    ThemeResource digital_resource;
     if (! loadPixmap(digital_resource, "digital/parts", tags, rrda_encoder)) {
       return;
     }
@@ -264,159 +258,33 @@ struct ThemeClockDraw::pImpl {
   }
 
 
-  // デジタル画像の描画位置を読み出し
-  void loadDigitalPosition(QMap<QString, QString>& tags) {
-
-    // "hh:mm ss x";
-    digital_positions_.clear();
-    digital_positions_.resize(10);
-
-    digitalPositionUpdate(0, tags, "digital/h1_xpos", "digital/h1_ypos");
-    digitalPositionUpdate(1, tags, "digital/h2_xpos", "digital/h2_ypos");
-
-    digitalPositionUpdate(2, tags, "digital/cl_xpos", "digital/cl_ypos");
-
-    digitalPositionUpdate(3, tags, "digital/m1_xpos", "digital/m1_ypos");
-    digitalPositionUpdate(4, tags, "digital/m2_xpos", "digital/m2_ypos");
-
-    digitalPositionUpdate(6, tags, "digital/s1_xpos", "digital/s1_ypos");
-    digitalPositionUpdate(7, tags, "digital/s2_xpos", "digital/s2_ypos");
-
-    digitalPositionUpdate(9, tags, "digital/ap_xpos", "digital/ap_ypos");
-  }
-
-
-  // デジタル文字の描画位置を設定
-  void digitalPositionUpdate(int index, QMap<QString, QString>& tags,
-                             const QString& x_tag, const QString& y_tag) {
-
-    int x = tags.value(x_tag, 0).toInt();
-    int y = tags.value(y_tag, 0).toInt();
-    digital_positions_[index] = QPoint(x, y);
-  }
-
-
   // フォームの初期化
   void initializeWidget(ThemeClockDraw* parent) {
 
+    resizeWidget(parent);
+  }
+
+
+  // リサイズ
+  void resizeWidget(ThemeClockDraw* parent) {
+
     QPixmap* base_pixmap = theme_resource_.pixmap.value("base/base_org");
-    region_ = new QRegion(base_pixmap->mask());
-    parent->resize(base_pixmap->size());
+    QSize size = base_pixmap->size();
+    QSize scaled_size =
+      QSize(static_cast<int>(scaling_percent_ * size.width() / 100.0),
+            static_cast<int>(scaling_percent_ * size.height() / 100.0));
+    QPixmap scaled_pixmap = base_pixmap->scaled(scaled_size);
+    region_ = new QRegion(scaled_pixmap.mask());
+    parent->resize(scaled_pixmap.size());
   }
 
 
   // 再描画
   void paintEvent(ThemeClockDraw* parent) {
 
-    QPainter painter(parent);
-    painter.setRenderHint(QPainter::SmoothPixmapTransform);
-
-    // ベース画像の描画
-    drawPixmap(painter, "base/base_org");
-
-    // 部品画像の描画
-    QTime time = QTime::currentTime();
-    updateDigital(painter, time.hour(), time.minute(), time.second());
-    updateAnalog(painter, time.hour(), time.minute(), time.second());
-  }
-
-
-  // アナログ部分の再描画
-  void updateAnalog(QPainter& painter, int hour, int minute, int second) {
-
-    // 針の角度を再計算
-    qreal analog_h = (360.0 * (hour / 12.0)) + (30.0 * (minute / 60.0));
-    drawPixmap(painter, "analog/hari_h", analog_h, CenterPosition);
-
-    qreal analog_m = 360.0 * minute / 60.0;
-    drawPixmap(painter, "analog/hari_m", analog_m, CenterPosition);
-
-    if (! compare_value("analog/sec", "on")) {
-      // 秒針は、指定があるときのみ描画する
-      qreal analog_s = 360.0 * second / 60.0;
-      drawPixmap(painter, "analog/hari_s", analog_s, CenterPosition);
-    }
-  }
-
-
-  // デジタル部分の再描画
-  void updateDigital(QPainter& painter, int hour, int minute, int second) {
-
-    enum { BufferSize = 11 };
-    char buffer[BufferSize] = "hh:mm ss x";
-
-    if (! compare_value("digital/sec", "on")) {
-      // 秒を描画する
-      snprintf(buffer, BufferSize, "%02d:%02d_%02d_%c",
-               hour, minute, second, (hour >= 12) ? 'P' : 'A');
-    } else {
-      // 秒は描画しない
-      snprintf(buffer, BufferSize, "%02d:%02d____%c",
-               hour, minute, (hour >= 12) ? 'P' : 'A');
-    }
-
-    if (! compare_value("digital/colon", "on")) {
-      // コロンを点滅させる
-      if (second & 0x01) {
-        buffer[2] = ' ';
-      }
-    }
-
-    // 描画処理
-    char digital_char[] = "_";
-    size_t n = strlen(buffer);
-    for (size_t i = 0; i < n; ++i) {
-      digital_char[0] = buffer[i];
-      QPixmap* parts = theme_resource_.pixmap.value(digital_char, NULL);
-      if (! parts) {
-        continue;
-      }
-
-      int x = digital_positions_[i].x();
-      int y = digital_positions_[i].y();
-      painter.drawPixmap(QPoint(x, y), *parts);
-    }
-  }
-
-
-  // 画像の描画
-  void drawPixmap(QPainter& painter,
-                  const QString& tag_name,
-                  qreal rotate_degree = 0,
-                  bool center_position = false) {
-
-    QPixmap* pixmap = theme_resource_.pixmap.value(tag_name, NULL);
-    if (! pixmap) {
-      return;
-    }
-
-    QRect offset = theme_resource_.offset.value(tag_name, QRect(0, 0, 0, 0));
-
-    if (center_position) {
-      // 回転前の状態をスタックに積んでおく
-      painter.save();
-
-      // 画像の中心で回転させてから、所定の場所に描画を行う
-      painter.translate(offset.x(), offset.y());
-      painter.rotate(rotate_degree);
-
-      int x = -offset.width() / 2;
-      int y = -offset.height() / 2;
-      painter.drawPixmap(QPoint(x, y), *pixmap);
-      painter.restore();
-
-    } else {
-      int x = offset.x();
-      int y = offset.y();
-      painter.drawPixmap(QPoint(x, y), *pixmap);
-    }
-  }
-
-
-  // 指定したタグが存在するか、の比較用
-  int compare_value(const QString& tag_name, const QString& compare_value) {
-
-    return theme_resource_.option.value(tag_name, "").compare(compare_value);
+    // 部品の再描画
+    ClockPartsDraw::redraw(parent, theme_resource_, digital_positions_,
+                           scaling_percent_);
   }
 };
 
@@ -479,3 +347,11 @@ QRegion* ThemeClockDraw::getRegion(void) {
 
   return (pimpl->theme_loaded_) ? pimpl->region_ : NULL;
 }
+
+
+// 描画の拡大率を設定
+void ThemeClockDraw::updateScalingPercent(size_t percent) {
+
+  pimpl->scaling_percent_ = percent;
+  pimpl->resizeWidget(this);
+}
