@@ -81,6 +81,14 @@ public:
   QRegion* getRegion(void);
 
 
+  /*!
+    \brief 描画の拡大率を設定
+
+    \param percernt [i] 描画の拡大率
+  */
+  void updateScalingPercent(size_t percent);
+
+
 signals:
   /*!
     \brief 終了シグナルを投げる
