@@ -4,7 +4,7 @@
 <context>
     <name>@default</name>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="157"/>
+        <location filename="ThemeClockWidget.cpp" line="173"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
@@ -17,30 +17,10 @@
         <translation>テーマ時計: 設定</translation>
     </message>
     <message>
-        <location filename="ClockSettingDialogForm.ui" line="144"/>
+        <location filename="ClockSettingDialogForm.ui" line="95"/>
         <source>&amp;Close</source>
         <translation>閉じる (&amp;C)</translation>
     </message>
-    <message>
-        <location filename="ClockSettingDialogForm.ui" line="80"/>
-        <source>Theme Config</source>
-        <translation>テーマ設定</translation>
-    </message>
-    <message>
-        <location filename="ClockSettingDialogForm.ui" line="88"/>
-        <source>unload current theme.</source>
-        <translation>テーマのアンロード.</translation>
-    </message>
-    <message>
-        <location filename="ClockSettingDialogForm.ui" line="104"/>
-        <source>Unload</source>
-        <translation>アンロード</translation>
-    </message>
-    <message>
-        <location filename="ClockSettingDialogForm.ui" line="98"/>
-        <source>Theme file will be unloaded.</source>
-        <translation>現在のテーマファイルを破棄し、初期フォームに戻します。</translation>
-    </message>
     <message>
         <location filename="ClockSettingDialogForm.ui" line="27"/>
         <source>Scale</source>
@@ -61,16 +41,21 @@
         <source>100 %</source>
         <translation>100 %</translation>
     </message>
+    <message>
+        <location filename="ClockSettingDialog.cpp" line="43"/>
+        <source>%1 %</source>
+        <translation>%1 %</translation>
+    </message>
 </context>
 <context>
     <name>QAction</name>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="156"/>
+        <location filename="ThemeClockWidget.cpp" line="172"/>
         <source>E&amp;xit</source>
         <translation>終了(&amp;x)</translation>
     </message>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="151"/>
+        <location filename="ThemeClockWidget.cpp" line="167"/>
         <source>Config</source>
         <translation>設定</translation>
     </message>
@@ -78,7 +63,7 @@
 <context>
     <name>QLabel</name>
     <message>
-        <location filename="ThemeClockDraw.cpp" line="59"/>
+        <location filename="ThemeClockDraw.cpp" line="54"/>
         <source>Drop theme file in this form.</source>
         <translation>テーマファイルを、このフォームにドロップして下さい。</translation>
     </message>
@@ -86,12 +71,12 @@
 <context>
     <name>ThemeClockWidget</name>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="276"/>
+        <location filename="ThemeClockWidget.cpp" line="293"/>
         <source>qtmclock</source>
         <translation>qtmclock</translation>
     </message>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="277"/>
+        <location filename="ThemeClockWidget.cpp" line="294"/>
         <source>%1 is not correct theme file.</source>
         <translation>%1 はテーマファイルではありません。</translation>
     </message>
