@@ -108,7 +108,9 @@ struct ThemeConfigWindow::pImpl {
 
   // フォームの初期化
   void initializeForm(ThemeConfigWindow* parent) {
-    static_cast<void>(parent);
+
+    // アイコンの適用
+    parent->setWindowIcon(QIcon(":icons/qtmclock_config_icon"));
 
     // Window Title の取得
     first_title_ = parent->windowTitle();
